Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(186)

Unified Diff: components/user_prefs/tracked/pref_hash_store_impl.h

Issue 2634403002: Use GetDeterministicMachineSpecificId instead of RLZ for device_id (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/user_prefs/tracked/pref_hash_store_impl.h
diff --git a/components/user_prefs/tracked/pref_hash_store_impl.h b/components/user_prefs/tracked/pref_hash_store_impl.h
index 1b5682eed4e83df46a039b50352e77da565756ff..76b6f7597e140ccbeb5a710bde0b239a3edbffe0 100644
--- a/components/user_prefs/tracked/pref_hash_store_impl.h
+++ b/components/user_prefs/tracked/pref_hash_store_impl.h
@@ -25,12 +25,12 @@ class PrefHashStoreImpl : public PrefHashStore {
};
// Constructs a PrefHashStoreImpl that calculates hashes using
// |seed| and |device_id| and stores them in |contents|.
//
// The same |seed| and |device_id| must be used to load and validate
// previously stored hashes in |contents|.
PrefHashStoreImpl(const std::string& seed,
- const std::string& device_id,
+ const std::string& legacy_device_id,
bool use_super_mac);
~PrefHashStoreImpl() override;
« no previous file with comments | « components/user_prefs/tracked/pref_hash_calculator_unittest.cc ('k') | components/user_prefs/tracked/pref_hash_store_impl.cc » ('j') | no next file with comments »
@@ -25,12 +25,12 @@ class PrefHashStoreImpl : public PrefHashStore {
};
// Constructs a PrefHashStoreImpl that calculates hashes using
- // |seed| and |device_id| and stores them in |contents|.
+ // |seed| and |legacy_device_id| and stores them in |contents|.
//
@@ -25,12 +25,12 @@ class PrefHashStoreImpl : public PrefHashStore {
//
- // The same |seed| and |device_id| must be used to load and validate
+ // The same |seed| and |legacy_device_id| must be used to load and validate
// previously stored hashes in |contents|.
PrefHashStoreImpl(const std::string& seed,

Powered by Google App Engine
This is Rietveld 408576698